#
# spec file for package python-python-dotenv
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-python-dotenv
Version:        1.1.0
Release:        2.1
Summary:        Python library for .env support
License:        BSD-3-Clause
URL:            https://github.com/theskumar/python-dotenv
Source:         https://github.com/theskumar/python-dotenv/archive/v%{version}.tar.gz#/python-dotenv-%{version}.tar.gz
# PATCH-FIX-OPENSUSE Avoid upstream click 8.2 bug -- gh#pallets/click#2913
Patch0:         avoid-click-8.2-bug.patch
BuildRequires:  %{python_module click >= 5.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 3.0.5}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module sh >= 2.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-click >= 5.0
# rubygem-dotenv also provides executable dotenv
Requires(post): update-alternatives
Requires(postun): update-alternatives
Suggests:       python-jupyter_ipython
# There is a very similar Python package which also used `dotenv` namespace
Conflicts:      python-dotenv
BuildArch:      noarch
%python_subpackages

%description
Add .env support to your Django/Flask apps in development and deployments.

%prep
%autosetup -p1 -n python-dotenv-%{version}

%build
export LANG=C.UTF-8
%pyproject_wheel

%install
export LANG=C.UTF-8
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/dotenv
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=C.UTF-8
mv %{buildroot}%{_bindir}/dotenv %{buildroot}%{_bindir}/dotenv.orig
# CLI tests require distribution to be found, and the correct executable installed
export PATH=%{buildroot}%{_bindir}:$PATH
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}
cp %{buildroot}%{_bindir}/dotenv-%{$python_bin_suffix} %{buildroot}%{_bindir}/dotenv
# ipython is optional and only available for python >= 3.7 in Tumbleweed
$python -m pytest -v -k "not ipython"
}
mv %{buildroot}%{_bindir}/dotenv.orig %{buildroot}%{_bindir}/dotenv

%post
%python_install_alternative dotenv

%postun
%python_uninstall_alternative dotenv

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/dotenv
%{python_sitelib}/dotenv/
%{python_sitelib}/python_dotenv-%{version}.dist-info

%changelog
* Wed May 14 2025 Steve Kowalik <steven.kowalik@suse.com>
- Add patch avoid-click-8.2-bug.patch:
  * Work around an upstream click 8.2.0 bug.
- Switch to pyproject macros.
* Wed Apr  9 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.1.0:
  * Add a security policy
  * Enhance dotenv run: Switch to execvpe for better resource management and
    signal handling
  * Add Python 3.13 trove classifier
  * Add support for python 3.13 and drop 3.8
  * docs: Update README.md
  * Some more s/Python-dotenv/python-dotenv/
  * add _is_debugger so load_dotenv will work in pdb
* Thu Feb  1 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.1:
  * Gracefully handle code which has been imported from a zipfile
  * Allow modules using load_dotenv to be reloaded when launched
    in a separate thread
  * Fix file not closed after deletion, handle error in the
    rewrite function
  * Use pathlib.Path in tests
  * Fix year in release date in changelog.md
  * Use https in README links
* Sun May  7 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.0:
  * Drop support for python 3.7, add python 3.12-dev
  * Handle situations where the cwd does not exist.
  * Use Python 3.11 non-beta in CI
  * Modernize variables code
  * Modernize main.py and parser.py code
  * Improve conciseness of cli.py and __init__.py
  * Improve error message for `get` and `list` commands when env
    file can't be opened
  * Updated License to align with BSD OSI template
  * Fix Out-of-scope error when "dest" variable is undefined
  * Fix IPython test warning about deprecated `magic`
  * Fix type hint for dotenv_path var, add StrPath alias
  * CLI: add support for invocations via 'python -m'.
  * `load_dotenv` function now returns `False`.
  * CLI: add --format= option to list command.
  * Drop Python 3.5 and 3.6 and upgrade GA
  * Use `open` instead of `io.open`.
  * Improve documentation for variables without a value
  * Add `parse_it` to Related Projects
  * Update README.md
  * Improve documentation with direct use of MkDocs
* Wed Apr 26 2023 John Vandenberg <jayvdb@gmail.com>
- Remove duplicate sle15_python_module_pythons
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Wed Apr 19 2023 Matej Cepl <mcepl@suse.com>
- Switch to single spec version build for PSP
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Apr 11 2022 Markéta Machová <mmachova@suse.com>
- Update to 0.20.0
  * The default value of the encoding parameter for load_dotenv and dotenv_values is now "utf-8" instead of None
  * Add --override/--no-override option to dotenv run
  * Raise ValueError if quote_mode isn't one of always, auto or never in set_key
  * Require Python 3.5 or a later version. Python 2 and 3.4 are no longer supported.
  * The stream argument of load_dotenv and dotenv_values can now be a text stream (IO[str]),
    which includes values like io.StringIO("foo") and open("file.env", "r")
  * Add support for Python 3.10.
  * Add encoding (Optional[str]) parameter to get_key, set_key and unset_key.
- Do not require mock
* Mon Feb 21 2022 Andreas Schneider <asn@cryptomilk.org>
- Skip building for python2
* Mon Dec  7 2020 Benjamin Greiner <code@bnavigator.de>
- Skip testing with optional jupyter_ipython. Jupyter is only
  available for Python >= 3.7
  gh#openSUSE/python-rpm-macros#66
* Wed Dec  2 2020 Michael Ströder <michael@stroeder.com>
- Update to 0.15.0
  * Add --export option to set to make it prepend the binding with export (#270 by @jadutter).
  * Make set command create the .env file in the current directory if no .env file was found (#270 by @jadutter).
  * Fix potentially empty expanded value for duplicate key (#260 by @bbc2).
  * Fix import error on Python 3.5.0 and 3.5.1 (#267 by @gongqingkui).
  * Fix parsing of unquoted values containing several adjacent space or tab characters (#277 by @bbc2, review by @x-yuri).
* Wed Aug  5 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.14.0
  * Privilege definition in file over the environment in variable expansion (#256 by
    [@elbehery95]).
  * Improve error message for when file isn't found (#245 by [@snobu]).
  * Use HTTPS URL in package meta data (#251 by [@ekohl]).
* Tue Jun 30 2020 John Vandenberg <jayvdb@gmail.com>
- Downgrade jupyter_ipython from Recommends to Suggests as
  python-dotenv is now a dependency of docker-compose
* Wed May 20 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.13.0
  * Add support for a Bash-like default value in variable expansion
  * Fix escaping of quoted values written by set_key
  * Few more fixes
* Wed Mar 18 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.12.0:
  * various fixes
* Mon Jul 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.10.3:
  * Small cleanups
* Sat May 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.10.2:
  * Add type hints and expose them to users (@qnighy)(#172)
  * load_dotenv and dotenv_values now accept an encoding parameter, defaults to None (@theskumar)(@earlbread)(#161)
  * Fix str/unicode inconsistency in Python 2: values are always str now. (@bbc2)(#121)
  * Fix Unicode error in Python 2, introduced in 0.10.0. (@bbc2)(#176)
* Thu Mar  7 2019 John Vandenberg <jayvdb@gmail.com>
- Add LANG=C.UTF-8 to %%check to fix tests on Leap
- Rename tarball to match name provided by PyPI
* Fri Feb 15 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for 0.10.1
